{% extends 'base.html' %}
{% load i18n %}

{% block title %}{% trans 'Logout' %}{% endblock %}

{% block body %}
    <div class="logout-page">
        <div class="container logout">
            <div class="row">
                <div class="col-md-4 col-md-offset-4">
                    <div class="login-panel panel panel-default">
                        <div class="panel-heading">
                            <h3 class="panel-title">{% trans 'Logout' %}</h3>
                        </div>
                        <div class="panel-body">
                            <p>{% trans 'Thanks for spending some quality time with the Web site today.' %}</p>
                            <p><a href="{% url 'IS:index-home' %}">{% trans 'Log in again' %}</a></p>
                        </div>
                    </div>
                </div>
                {% block below-login-form %}{% endblock %}
        </div>
    </div>
{% endblock %}
