$IMG_URL: '../is_core/images'
$font-family: Helvetica, Arial, sans-serif

// COLORS
$yellow: #fafa00
$red: #ed3535
$blue: #428bca
$green: #47ad6d
$gray: #383838
$light-gray: #aeaeae
$mid-gray: #888

$selection-bg-clr: #08b1ff
$selection-clr: #fff
$focus-clr: #428bca

$body-bg: #f8f8f8
$content-bg: #fbfbfb

$tab-a-color: #555

// MODAL
$modal-header: #474747
$modal-width: 618px

// HEADERS
$h4-gray: #737373

// LINKS
$a-clr: $blue
$a-clr-hover: $blue
$a-clr-active: $blue

$icon-dark: #a1a1a1

$user-img-size: 40px
$user-img-small-size: 30px
$ac-img-small-size: 20px

// BUTTONS
$btn-dec-border-clr: #f2e10d
$btn-pri-clr: #fff
$btn-pri-border-clr: #000
$btn-bg-disabled: #94ddff
$btn-def-clr: #3d3d3d
$btn-def-border-clr: #d8d8d8

// INPUTS
$input-border-clr: #ccc
$input-bg-clr: #fbfbfb
$input-clr: #414141
$input-height: 40px
$select-bg-clr: #fbfbfb

$select-arr: $IMG_URL + '/select-arrow.png'

$label-clr: #565656
$label-clr-login: #929292

$ac-highlighted: #5bc0de

// NAVIGATION
$side-bar-width: 232px
$nav-bar-top-height: 90px

$bread-crumbs-clr: #000

$close-clr: $red

// STATES
$state-new: $red
$state-in-progress: $blue
$state-done: $green
$state-cancel: #a4a4a4

// LAYOUT
$content-pad: 28px

// FLASH MESSAGES
$alert-red: $red
$alert-red-border: #de0e0e
